Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(73)

Unified Diff: chrome/common/search/instant_types.h

Issue 2532103002: Add support for components/ntp_tiles in InstantService (Closed)
Patch Set: rebase Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/render_messages.h ('k') | chrome/common/search/instant_types.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/search/instant_types.h
diff --git a/chrome/common/search/instant_types.h b/chrome/common/search/instant_types.h
index 7c7afa84f924270e9a4744a27f1dce1a8bce469b..552a251bc2785d99591fa413824c75c19c3a6690 100644
--- a/chrome/common/search/instant_types.h
+++ b/chrome/common/search/instant_types.h
@@ -11,6 +11,7 @@
#include <utility>
#include "base/strings/string16.h"
+#include "components/ntp_tiles/ntp_tile_source.h"
#include "url/gurl.h"
// ID used by Instant code to refer to objects (e.g. Autocomplete results, Most
@@ -141,9 +142,8 @@ struct InstantMostVisitedItem {
// The external URL of the favicon associated with this page.
GURL favicon;
- // True if it's a server side suggestion.
- // Otherwise, it's a client side suggestion.
- bool is_server_side_suggestion;
+ // The source of the item, e.g. server-side or client-side.
+ ntp_tiles::NTPTileSource source;
};
// An InstantMostVisitedItem along with its assigned restricted ID.
« no previous file with comments | « chrome/common/render_messages.h ('k') | chrome/common/search/instant_types.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698